/*

Aggregate summary output into NAS project outcomes

*/

* real interest rate for discounting government expenditures 
* See http://www.ssa.gov/oact/tr/2013/V_B_econ.html#209902 - using 2.9, which is the longer term (2022 and later) real interest rate for the intermediate cost scenario
local govtrr 0.029

*local slist fem_aime_1978 fem_aime_1978_backtime fem_aime_2010 fem_aime_nofvars_1978 fem_aime_nofvars_2010 rel_aime_only_1978 rel_aime_only_2010 aimequint_waldron07_1978 aimequint_waldron07_2010

* local slist fem_aime_2010 fem_aime_nofvars_2010 fem_aime_backtime_2010 fem_aime_1978 fem_aime_nofvars_1978 fem_aime_backtime_1978 aimeq_waldron07_1978 aimeq_waldron07_2010

* local slist fem_aime_2010 fem_aime_nofvars_2010 fem_aime_backtime_2010 fem_aime_1978 fem_aime_nofvars_1978 fem_aime_backtime_1978 aimeq_waldron07_1978 aimeq_waldron07_2010


local slist fem_aime_backtime_2040 fem_aime_backtime_2010 fem_aime_backtime_1978 aimeq_waldron07_2040 aimeq_waldron07_2010 aimeq_waldron07_1978

*local slist status_quo ssamortadj78_only target78

foreach s of local slist {
	tempfile tf_`s'
}

foreach yr in 2010 2023 {
	local age = `yr' - 1959

	foreach f of local slist {
		
		use "../output/`f'/`f'_summary.dta", clear
		
		* use this to aggregate over a subset of the years (e.g., ages 59+)
		drop if year < `yr'
		
		foreach q in 1 2 3 4 {
			foreach sex in m f {
				local qs `q'`sex'
			
				* turn missing years into zeros where needed
				replace m_startpop_aimequ`qs' = 0 if missing(m_startpop_aimequ`qs')
				replace m_endpop_aimequ`qs' = 0 if missing(m_endpop_aimequ`qs')
				replace pop_healthy_aimequ`qs' = 0 if missing(pop_healthy_aimequ`qs')
				replace t_qaly_aimequ`qs' = 0 if missing(t_qaly_aimequ`qs')
				replace x_raime_aimequ`qs' = 0 if missing(x_raime_aimequ`qs')
				
				/* Expected age at death */
				gen agedied_qu`qs' = (d_age_aimequ`qs'-1) * (m_startpop_aimequ`qs' - m_endpop_aimequ`qs') / m_startpop_aimequ`qs'[1]
				replace agedied_qu`qs' = 0 if missing(agedied_qu`qs')
				
				/* QALYs */
				gen avgqaly_qu`qs' = 2.0 * t_qaly_aimequ`qs' / (m_startpop_aimequ`qs'[1] * 1000000.0)
				replace avgqaly_qu`qs' = 0 if missing(avgqaly_qu`qs')
				
				/* Lifetime earnings */
				gen avg_raimeyr_qu`qs' = x_raime_aimequ`qs' * (m_startpop_aimequ`qs' - m_endpop_aimequ`qs') / m_startpop_aimequ`qs'[1]
				replace avg_raimeyr_qu`qs' = 0 if missing(avg_raimeyr_qu`qs')
		
				/* Non-disabled life years after age 50 (number healthy people x 2 years) */
				gen healthy_yrs_qu`qs' = 2.0 * pop_healthy_aimequ`qs' / m_startpop_aimequ`qs'[1]
				replace healthy_yrs_qu`qs' = 0 if missing(healthy_yrs_qu`qs')
					
				/* Government support (discount to present value with govtrr rate)
				!!!Now discounting medical spending, too!!! */
				foreach v in t_ssben t_ssiben t_diben t_igxfr t_totmd t_mcare t_caidmd {
					replace `v'_aimequ`qs' = 0 if missing(`v'_aimequ`qs')
					gen `v'pv_qu`qs' = (`v'_aimequ`qs'[_n] / ((1 + `govtrr') ^ (year-2010))) + (.5*(`v'_aimequ`qs'[_n]+`v'_aimequ`qs'[_n+1]) / ((1 + `govtrr') ^ ((year+1)-2010)))
					gen avg_`v'pv_qu`qs' = `v'pv_qu`qs' / (m_startpop_aimequ`qs'[1] * 1000000.0)
				}		
		
			}
		}
	#d ;
		collapse 
			(sum) agedied_qu1m (sum) agedied_qu2m (sum) agedied_qu3m (sum) agedied_qu4m 
			(sum) agedied_qu1f (sum) agedied_qu2f (sum) agedied_qu3f (sum) agedied_qu4f 
			(sum) avgqaly_qu1m (sum) avgqaly_qu2m (sum) avgqaly_qu3m (sum) avgqaly_qu4m 
			(sum) avgqaly_qu1f (sum) avgqaly_qu2f (sum) avgqaly_qu3f (sum) avgqaly_qu4f 
			(sum) healthy_yrs_qu1m (sum) healthy_yrs_qu2m (sum) healthy_yrs_qu3m (sum) healthy_yrs_qu4m  
			(sum) healthy_yrs_qu1f (sum) healthy_yrs_qu2f (sum) healthy_yrs_qu3f (sum) healthy_yrs_qu4f  
			(sum) avg_raimeyr_qu1m (sum) avg_raimeyr_qu2m (sum) avg_raimeyr_qu3m (sum) avg_raimeyr_qu4m  
			(sum) avg_raimeyr_qu1f (sum) avg_raimeyr_qu2f (sum) avg_raimeyr_qu3f (sum) avg_raimeyr_qu4f  
			(sum) t_totmdpv_qu1m (sum) t_totmdpv_qu2m (sum) t_totmdpv_qu3m (sum) t_totmdpv_qu4m  
			(sum) t_totmdpv_qu1f (sum) t_totmdpv_qu2f (sum) t_totmdpv_qu3f (sum) t_totmdpv_qu4f  
			(sum) t_mcarepv_qu1m (sum) t_mcarepv_qu2m (sum) t_mcarepv_qu3m (sum) t_mcarepv_qu4m  
			(sum) t_mcarepv_qu1f (sum) t_mcarepv_qu2f (sum) t_mcarepv_qu3f (sum) t_mcarepv_qu4f  
			(sum) t_caidmdpv_qu1m (sum) t_caidmdpv_qu2m (sum) t_caidmdpv_qu3m (sum) t_caidmdpv_qu4m  
			(sum) t_caidmdpv_qu1f (sum) t_caidmdpv_qu2f (sum) t_caidmdpv_qu3f (sum) t_caidmdpv_qu4f  
			(sum) avg_t_totmdpv_qu1m (sum) avg_t_totmdpv_qu2m (sum) avg_t_totmdpv_qu3m (sum) avg_t_totmdpv_qu4m  
			(sum) avg_t_totmdpv_qu1f (sum) avg_t_totmdpv_qu2f (sum) avg_t_totmdpv_qu3f (sum) avg_t_totmdpv_qu4f  
			(sum) avg_t_mcarepv_qu1m (sum) avg_t_mcarepv_qu2m (sum) avg_t_mcarepv_qu3m (sum) avg_t_mcarepv_qu4m  
			(sum) avg_t_mcarepv_qu1f (sum) avg_t_mcarepv_qu2f (sum) avg_t_mcarepv_qu3f (sum) avg_t_mcarepv_qu4f  
			(sum) avg_t_caidmdpv_qu1m (sum) avg_t_caidmdpv_qu2m (sum) avg_t_caidmdpv_qu3m (sum) avg_t_caidmdpv_qu4m  
			(sum) avg_t_caidmdpv_qu1f (sum) avg_t_caidmdpv_qu2f (sum) avg_t_caidmdpv_qu3f (sum) avg_t_caidmdpv_qu4f  
			(sum) t_ssbenpv_qu1m (sum) t_ssbenpv_qu2m (sum) t_ssbenpv_qu3m (sum) t_ssbenpv_qu4m 
			(sum) t_ssbenpv_qu1f (sum) t_ssbenpv_qu2f (sum) t_ssbenpv_qu3f (sum) t_ssbenpv_qu4f 
			(sum) t_ssibenpv_qu1m (sum) t_ssibenpv_qu2m (sum) t_ssibenpv_qu3m (sum) t_ssibenpv_qu4m  
			(sum) t_ssibenpv_qu1f (sum) t_ssibenpv_qu2f (sum) t_ssibenpv_qu3f (sum) t_ssibenpv_qu4f   
			(sum) t_dibenpv_qu1m (sum) t_dibenpv_qu2m (sum) t_dibenpv_qu3m (sum) t_dibenpv_qu4m  
			(sum) t_dibenpv_qu1f (sum) t_dibenpv_qu2f (sum) t_dibenpv_qu3f (sum) t_dibenpv_qu4f  
			(sum) t_igxfrpv_qu1m (sum) t_igxfrpv_qu2m (sum) t_igxfrpv_qu3m (sum) t_igxfrpv_qu4m  
			(sum) t_igxfrpv_qu1f (sum) t_igxfrpv_qu2f (sum) t_igxfrpv_qu3f (sum) t_igxfrpv_qu4f  
			(sum) avg_t_ssbenpv_qu1m (sum) avg_t_ssbenpv_qu2m (sum) avg_t_ssbenpv_qu3m (sum) avg_t_ssbenpv_qu4m  
			(sum) avg_t_ssbenpv_qu1f (sum) avg_t_ssbenpv_qu2f (sum) avg_t_ssbenpv_qu3f (sum) avg_t_ssbenpv_qu4f 
			(sum) avg_t_ssibenpv_qu1m (sum) avg_t_ssibenpv_qu2m (sum) avg_t_ssibenpv_qu3m (sum) avg_t_ssibenpv_qu4m 
			(sum) avg_t_ssibenpv_qu1f (sum) avg_t_ssibenpv_qu2f (sum) avg_t_ssibenpv_qu3f (sum) avg_t_ssibenpv_qu4f  
			(sum) avg_t_dibenpv_qu1m (sum) avg_t_dibenpv_qu2m (sum) avg_t_dibenpv_qu3m (sum) avg_t_dibenpv_qu4m  
			(sum) avg_t_dibenpv_qu1f (sum) avg_t_dibenpv_qu2f (sum) avg_t_dibenpv_qu3f (sum) avg_t_dibenpv_qu4f  
			(sum) avg_t_igxfrpv_qu1m (sum) avg_t_igxfrpv_qu2m (sum) avg_t_igxfrpv_qu3m (sum) avg_t_igxfrpv_qu4m  
			(sum) avg_t_igxfrpv_qu1f (sum) avg_t_igxfrpv_qu2f (sum) avg_t_igxfrpv_qu3f (sum) avg_t_igxfrpv_qu4f  
	
		;
		#d cr
	
		gen scen = "`f'"
		li
		save `tf_`f'', replace
	
	
	}


	*use `tf_qudummies1978_upper', clear
	clear
	foreach s of local slist {
		append using `tf_`s''
	}

	sort scen
	li scen agedied_qu1f agedied_qu2f agedied_qu3f agedied_qu4f agedied_qu1m agedied_qu2m agedied_qu3m agedied_qu4m
	*li scen agedied_qu1m agedied_qu2m agedied_qu3m agedied_qu4m agedied_qu5m
	* save nas_diffs2.dta, replace
	save nas_diffs_`age'.dta, replace
} /* year loop */

